//+------------------------------------------------------------------+
//|   Qualitative Quantitative Estimation Indicator for Metatrader 4 |
//|                                     Copyright  2006Roman Ignatov |
//|                                   mailto:roman.ignatov@gmail.com |
//+------------------------------------------------------------------+
#property copyright "Copyright  200 Roman Ignatov"
#property link      "mailto:roman.ignatov@gmail.com"

#property indicator_separate_window

#property indicator_buffers 3

#property indicator_color1 DeepSkyBlue
#property indicator_style1 STYLE_SOLID
#property indicator_width1 2

#property indicator_color2 LightPink
#property indicator_style2 STYLE_DOT
#property indicator_width2 1

#property indicator_color3 OrangeRed
#property indicator_style3 STYLE_SOLID
#property indicator_width3 1

#property indicator_level1 50.00
#property indicator_levelcolor DeepSkyBlue
#property indicator_levelstyle STYLE_SOLID
#property indicator_levelwidth 1


extern int SF = 5;

extern int MOM_Period = 14;

extern int MOM_Price = PRICE_CLOSE;

extern int MA_Mode = MODE_EMA;

extern double Slow = 4.236;

extern double Fast = 2.618;


int Wilders_Period;
int StartBar;

double TrLevelSlow[];
double TrLevelFast[];
double AtrMom[];
double MaAtrMom[];
double Mom[];
double MomMa[];

int init()
{
    Wilders_Period = MOM_Period * 2 - 1;
    if (Wilders_Period < SF)
        StartBar = SF;
    else
        StartBar = Wilders_Period;
        
    IndicatorBuffers(6);
    SetIndexBuffer(0, MomMa);
    SetIndexStyle(0, DRAW_LINE);
    SetIndexLabel(0, "Value 1");
    SetIndexDrawBegin(0, StartBar);
    SetIndexStyle(1, DRAW_LINE);
    SetIndexBuffer(1, TrLevelFast);
    SetIndexLabel(1, "Value 2");
    SetIndexDrawBegin(1, StartBar);
    SetIndexStyle(2, DRAW_LINE);
    SetIndexBuffer(2, TrLevelSlow);
    SetIndexLabel(2, "Value 3");
    SetIndexDrawBegin(2, StartBar);
    SetIndexBuffer(3, AtrMom);
    SetIndexBuffer(4, MaAtrMom);
    SetIndexBuffer(5, Mom);
    IndicatorShortName(StringConcatenate("QQE_Mom(", SF, ")"));
    return(0);
}


int start()
{
    int counted, i;
    double mom0, mom1, dar, tr, dv;
    double mom2, dar2, tr2, dv2;
    
    if(Bars <= StartBar)
        return (0);

    counted = IndicatorCounted();
    if(counted < 1)
        for(i = Bars - StartBar; i < Bars; i++)
        {
            TrLevelSlow[i] = 0.0;
            TrLevelFast[i] = 0.0;
            AtrMom[i] = 0.0;
            MaAtrMom[i] = 0.0;
            Mom[i] = 0.0;
            MomMa[i] = 0.0;
        }
    
    counted = Bars - counted - 1;
        
    for (i = counted; i >= 0; i--)
        Mom[i] = (iMomentum(NULL, 0, MOM_Period, MOM_Price, i)) - 50;

    for (i = counted; i >= 0; i--)
    {
        MomMa[i] = iMAOnArray(Mom, 0, SF, 0, MA_Mode, i);
        AtrMom[i] = MathAbs(MomMa[i + 1] - MomMa[i]);
    }

    for (i = counted; i >= 0; i--)
        MaAtrMom[i] = iMAOnArray(AtrMom, 0, Wilders_Period, 0, MA_Mode, i);

    i = counted + 1;
    tr = TrLevelSlow[i];
    tr2 = TrLevelFast[i];
    mom1 = iMAOnArray(Mom, 0, SF, 0, MA_Mode, i);
    mom2 = iMAOnArray(Mom, 0, SF, 0, MA_Mode, i);
    while (i > 0)
    {
        i--;
        mom0 = iMAOnArray(Mom, 0, SF, 0, MA_Mode, i);
        dar = iMAOnArray(MaAtrMom, 0, Wilders_Period, 0, MA_Mode, i) * Slow;

        dv = tr;
        if (mom0 < tr)
        {
            tr = mom0 + dar;
            if (mom1 < dv)
                if (tr > dv)
                    tr = dv;
        }
        else if (mom0 > tr)
        {
            tr = mom0 - dar;
            if (mom1 > dv)
                if (tr < dv)
                    tr = dv;
        }
        TrLevelSlow[i] = tr;
        mom1 = mom0;

        dar2 = iMAOnArray(MaAtrMom, 0, Wilders_Period, 0, MA_Mode, i) * Fast; 
        dv2 = tr2;
        if (mom0 < tr2)
        {
            tr2 = mom0 + dar2;
            if (mom2 < dv2)
                if (tr2 > dv2)
                    tr2 = dv2;
        }
        else if (mom0 > tr2)
        {
            tr2 = mom0 - dar2;
            if (mom2 > dv2)
                if (tr2 < dv2)
                    tr2 = dv2;
        }
        TrLevelFast[i] = tr2;
        mom2 = mom0;


    }
    
    return(0);
}


